| Type: | Package |
| Title: | Grouped Hyper Data Frame |
| Version: | 0.4.4 |
| Date: | 2026-07-28 |
| Description: | To aggregate a hyper data frame, defined in the package 'spatstat.geom', according to a grouping structure. To facilitate downstream analysis based on a "grouped" hyper data frame. The author has retired from academic research. Accordingly, this package should not be considered a validated tool for use in peer-reviewed publications or as the basis for grant applications. Backward compatibility with user-code published in <doi:10.1093/bioinformatics/btaf430> is not maintained in versions >= 0.4.0 (June 2026) of this package. The authors of those publications are the appropriate contacts for reproducibility inquiries. |
| LazyData: | true |
| LazyDataCompression: | xz |
| Encoding: | UTF-8 |
| License: | GPL-2 |
| Language: | en-US |
| URL: | https://github.com/tingtingzhan/groupedHyperframe |
| Depends: | R (≥ 4.6) |
| Imports: | cli, spatstat.geom |
| Suggests: | survival, spatstat.data |
| Config/roxygen2/version: | 8.0.0 |
| Config/roxygen2/markdown: | TRUE |
| NeedsCompilation: | no |
| Packaged: | 2026-07-28 05:06:52 UTC; tingtingzhan |
| Author: | Tingting Zhan |
| Maintainer: | Tingting Zhan <tingtingzhan@gmail.com> |
| Repository: | CRAN |
| Date/Publication: | 2026-07-28 05:20:02 UTC |
groupedHyperframe: Grouped Hyper Data Frame
Description
To aggregate a hyper data frame, defined in the package 'spatstat.geom', according to a grouping structure. To facilitate downstream analysis based on a "grouped" hyper data frame. The author has retired from academic research. Accordingly, this package should not be considered a validated tool for use in peer-reviewed publications or as the basis for grant applications. Backward compatibility with user-code published in doi:10.1093/bioinformatics/btaf430 is not maintained in versions >= 0.4.0 (June 2026) of this package. The authors of those publications are the appropriate contacts for reproducibility inquiries.
Note
This R package author has retired from academic research.
Accordingly, this package should not be considered a validated tool for use in peer-reviewed publications or as the basis for grant applications.
Backward compatibility with user-code published in the following publications is not maintained in versions >= 0.4.0 of this package. The authors of those publications are the appropriate contacts for reproducibility inquiries.
doi:10.1093/bioinformatics/btaf430
Author(s)
Maintainer: Tingting Zhan tingtingzhan@gmail.com (ORCID)
Authors:
Tingting Zhan tingtingzhan@gmail.com (ORCID)
See Also
Useful links:
Aggregate Hyper Data Frame
Description
To aggregate a hyperframe.
Usage
## S3 method for class 'hyperframe'
aggregate(x, by, ...)
Arguments
x |
|
by |
two-sided formula,
whose right-hand-side contains only the regular-column names of the input |
... |
additional parameters of the function aggregate.data.frame,
except for |
Value
The S3 method aggregate.hyperframe() returns a hyperframe.
Examples
spatstat.data::demohyper |>
aggregate(by = . ~ Group, FUN = unique)
spatstat.data::flu |>
aggregate(by = . - frameid ~ virustype:stain, FUN = unique)
spatstat.data::osteo |>
aggregate(by = . - brick ~ shortid, FUN = unique)
Aggregate, an Alternative formula-Interface
Description
An alternative aggregation function with a formula-interface, to avoid the cbind-operation in the function aggregate.formula.
Usage
aggregate2(data, by, ...)
Arguments
data |
|
by |
a two-sided formula |
... |
additional parameters of the function aggregate.data.frame,
except for |
Details
The cbind-operation in the function aggregate.formula messes up with column(s) that are
The function aggregate.data.frame only accepts
a list of factors for the parameter by.
Therefore, the function aggregate2() is created to take care of
the factor and Surv columns of the input,
with a formula-interface.
Value
The function aggregate2() returns a data.frame.
Note
The function aggregate.data.frame is the workhorse of the function aggregate.formula.
The function as.hyperframe.data.frame is designed to handle the list-columns returned by the function aggregate.
Augment Hypercolumn(s) for gam
Description
Augment all numeric vector hypercolumns in a hyperframe for gam.
Usage
aug4gam(x, ...)
## S3 method for class 'data.frame'
aug4gam(x, ...)
## S3 method for class 'hyperframe'
aug4gam(x, ...)
## S3 method for class 'vectorlist'
aug4gam(x, ...)
Arguments
x |
see Usage |
... |
additional parameters, currently of no use |
Value
The S3 generic function aug4gam() returns a data.frame.
Author(s)
Tingting Zhan, Erjia Cui
Vector-List
Description
To determine if an R object is a list of vectors with the same storage.mode, length and attributes.
Usage
is.vectorlist(
x,
mode = c("logical", "integer", "numeric", "double", "character")
)
Arguments
x |
a listof |
mode |
character scalar other than |
Value
The function is.vectorlist() returns a logical scalar.
Examples
spatstat.data::Kovesi$values |>
is.vectorlist(mode = 'character') |>
stopifnot()
spatstat.data::Kovesi$values |>
is.vectorlist(mode = 'numeric')
Hyper Data Frame with One-and-Only-One ppp-Hyper Column
Description
To create a hyper data frame with one-and-only-one ppp-hyper column.
Usage
pppBy(
marks,
coords = ~x + y,
by,
data,
window = owin(xrange = range(.x), yrange = range(.y)),
...
)
Arguments
marks |
one-sided formula, e.g.,
|
coords |
one-sided formula, variable names
of the |
by |
two-sided formula |
data |
|
window |
observation window owin,
default value is the |
... |
additional parameters of the function ppp |
Value
The function pppBy() returns a hyper data frame
with one-and-only-one
ppp-hyper column.
wrobel_lung
Description
From Dr. Julia Wrobel's data https://sph.emory.edu/profile/faculty/julia-wrobel.
Usage
wrobel_lung